import 'package:flutter/material.dart';
import 'package:flutter_svg/flutter_svg.dart';
import 'package:path/path.dart' as p;

/// ikonate icons
///
/// - build svg for icony_ikonate icon libraries
/// - constants link to svg icon resources
class Ikonate extends StatelessWidget {
  final String assetName;
  final bool matchTextDirection;
  final AssetBundle? bundle;
  final String? package;
  final double? width;
  final double? height;
  final BoxFit fit;
  final AlignmentGeometry alignment;
  final bool allowDrawingOutsideViewBox;
  final WidgetBuilder? placeholderBuilder;
  final Color? color;
  final BlendMode colorBlendMode;
  final String? semanticsLabel;
  final bool excludeFromSemantics;
  final Clip clipBehavior;
  final bool cacheColorFilter;
  final SvgTheme? theme;

  /// construct IconData
  const Ikonate(this.assetName,
      {Key? key,
      this.matchTextDirection = false,
      this.bundle,
      this.package,
      this.width,
      this.height,
      this.fit = BoxFit.contain,
      this.alignment = Alignment.center,
      this.allowDrawingOutsideViewBox = false,
      this.placeholderBuilder,
      this.color,
      this.colorBlendMode = BlendMode.srcIn,
      this.semanticsLabel,
      this.excludeFromSemantics = false,
      this.clipBehavior = Clip.hardEdge,
      this.cacheColorFilter = false,
      this.theme})
      : super(key: key);

  /// build widget for svg asset
  static Widget svgAsset(String assetName,
      {Key? key,
      bool matchTextDirection = false,
      AssetBundle? bundle,
      String? package,
      double? width,
      double? height,
      BoxFit fit = BoxFit.contain,
      AlignmentGeometry alignment = Alignment.center,
      bool allowDrawingOutsideViewBox = false,
      WidgetBuilder? placeholderBuilder,
      Color? color,
      BlendMode colorBlendMode = BlendMode.srcIn,
      String? semanticsLabel,
      bool excludeFromSemantics = false,
      Clip clipBehavior = Clip.hardEdge,
      bool cacheColorFilter = false,
      SvgTheme? theme}) {
    final path = p.join(
      // external library
      'packages/icony/assets/images/icony_ikonate/',
      // local library
      // 'assets/images/icony_ikonate/',
      assetName,
    );
    return SvgPicture.asset(
      path,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  @override
  Widget build(BuildContext context) {
    return svgAsset(
      assetName,
      key: key,
      matchTextDirection: matchTextDirection,
      bundle: bundle,
      package: package,
      width: width,
      height: height,
      fit: fit,
      alignment: alignment,
      allowDrawingOutsideViewBox: allowDrawingOutsideViewBox,
      placeholderBuilder: placeholderBuilder,
      color: color,
      colorBlendMode: colorBlendMode,
      semanticsLabel: semanticsLabel,
      excludeFromSemantics: excludeFromSemantics,
      clipBehavior: clipBehavior,
      cacheColorFilter: cacheColorFilter,
      theme: theme,
    );
  }

  /// map constant accessibility_human to accessibility-human.svg file
  static const String accessibility_human = 'accessibility-human.svg';

  /// map constant accessibility to accessibility.svg file
  static const String accessibility = 'accessibility.svg';

  /// map constant activity to activity.svg file
  static const String activity = 'activity.svg';

  /// map constant add_to_list to add-to-list.svg file
  static const String add_to_list = 'add-to-list.svg';

  /// map constant add to add.svg file
  static const String add = 'add.svg';

  /// map constant alarm to alarm.svg file
  static const String alarm = 'alarm.svg';

  /// map constant align_center to align-center.svg file
  static const String align_center = 'align-center.svg';

  /// map constant align_left to align-left.svg file
  static const String align_left = 'align-left.svg';

  /// map constant align_right to align-right.svg file
  static const String align_right = 'align-right.svg';

  /// map constant anchor to anchor.svg file
  static const String anchor = 'anchor.svg';

  /// map constant aperture to aperture.svg file
  static const String aperture = 'aperture.svg';

  /// map constant apps_alt to apps-alt.svg file
  static const String apps_alt = 'apps-alt.svg';

  /// map constant apps to apps.svg file
  static const String apps = 'apps.svg';

  /// map constant arrow_down_circle to arrow-down-circle.svg file
  static const String arrow_down_circle = 'arrow-down-circle.svg';

  /// map constant arrow_down to arrow-down.svg file
  static const String arrow_down = 'arrow-down.svg';

  /// map constant arrow_left_bottom to arrow-left-bottom.svg file
  static const String arrow_left_bottom = 'arrow-left-bottom.svg';

  /// map constant arrow_left_circle to arrow-left-circle.svg file
  static const String arrow_left_circle = 'arrow-left-circle.svg';

  /// map constant arrow_left_top to arrow-left-top.svg file
  static const String arrow_left_top = 'arrow-left-top.svg';

  /// map constant arrow_left to arrow-left.svg file
  static const String arrow_left = 'arrow-left.svg';

  /// map constant arrow_right_bottom to arrow-right-bottom.svg file
  static const String arrow_right_bottom = 'arrow-right-bottom.svg';

  /// map constant arrow_right_circle to arrow-right-circle.svg file
  static const String arrow_right_circle = 'arrow-right-circle.svg';

  /// map constant arrow_right_top to arrow-right-top.svg file
  static const String arrow_right_top = 'arrow-right-top.svg';

  /// map constant arrow_right to arrow-right.svg file
  static const String arrow_right = 'arrow-right.svg';

  /// map constant arrow_up_circle to arrow-up-circle.svg file
  static const String arrow_up_circle = 'arrow-up-circle.svg';

  /// map constant arrow_up to arrow-up.svg file
  static const String arrow_up = 'arrow-up.svg';

  /// map constant back_alt to back-alt.svg file
  static const String back_alt = 'back-alt.svg';

  /// map constant back_left to back-left.svg file
  static const String back_left = 'back-left.svg';

  /// map constant back_right to back-right.svg file
  static const String back_right = 'back-right.svg';

  /// map constant back to back.svg file
  static const String back = 'back.svg';

  /// map constant bag to bag.svg file
  static const String bag = 'bag.svg';

  /// map constant basket to basket.svg file
  static const String basket = 'basket.svg';

  /// map constant basketball to basketball.svg file
  static const String basketball = 'basketball.svg';

  /// map constant battery_alt to battery-alt.svg file
  static const String battery_alt = 'battery-alt.svg';

  /// map constant battery_charging to battery-charging.svg file
  static const String battery_charging = 'battery-charging.svg';

  /// map constant battery_full to battery-full.svg file
  static const String battery_full = 'battery-full.svg';

  /// map constant battery_low to battery-low.svg file
  static const String battery_low = 'battery-low.svg';

  /// map constant battery_medium to battery-medium.svg file
  static const String battery_medium = 'battery-medium.svg';

  /// map constant battery to battery.svg file
  static const String battery = 'battery.svg';

  /// map constant bell to bell.svg file
  static const String bell = 'bell.svg';

  /// map constant bike to bike.svg file
  static const String bike = 'bike.svg';

  /// map constant bin to bin.svg file
  static const String bin = 'bin.svg';

  /// map constant bluetooth to bluetooth.svg file
  static const String bluetooth = 'bluetooth.svg';

  /// map constant bolt to bolt.svg file
  static const String bolt = 'bolt.svg';

  /// map constant book_opened to book-opened.svg file
  static const String book_opened = 'book-opened.svg';

  /// map constant book to book.svg file
  static const String book = 'book.svg';

  /// map constant bookmark to bookmark.svg file
  static const String bookmark = 'bookmark.svg';

  /// map constant box_alt to box-alt.svg file
  static const String box_alt = 'box-alt.svg';

  /// map constant box_alt2 to box-alt2.svg file
  static const String box_alt2 = 'box-alt2.svg';

  /// map constant box to box.svg file
  static const String box = 'box.svg';

  /// map constant brightness to brightness.svg file
  static const String brightness = 'brightness.svg';

  /// map constant bug to bug.svg file
  static const String bug = 'bug.svg';

  /// map constant calendar_add to calendar-add.svg file
  static const String calendar_add = 'calendar-add.svg';

  /// map constant calendar_decline to calendar-decline.svg file
  static const String calendar_decline = 'calendar-decline.svg';

  /// map constant calendar_event to calendar-event.svg file
  static const String calendar_event = 'calendar-event.svg';

  /// map constant calendar to calendar.svg file
  static const String calendar = 'calendar.svg';

  /// map constant camera_rear to camera-rear.svg file
  static const String camera_rear = 'camera-rear.svg';

  /// map constant camera to camera.svg file
  static const String camera = 'camera.svg';

  /// map constant cancel to cancel.svg file
  static const String cancel = 'cancel.svg';

  /// map constant car_alt to car-alt.svg file
  static const String car_alt = 'car-alt.svg';

  /// map constant car to car.svg file
  static const String car = 'car.svg';

  /// map constant cards to cards.svg file
  static const String cards = 'cards.svg';

  /// map constant cart_add to cart-add.svg file
  static const String cart_add = 'cart-add.svg';

  /// map constant cart to cart.svg file
  static const String cart = 'cart.svg';

  /// map constant celluar to celluar.svg file
  static const String celluar = 'celluar.svg';

  /// map constant chart to chart.svg file
  static const String chart = 'chart.svg';

  /// map constant chat_add to chat-add.svg file
  static const String chat_add = 'chat-add.svg';

  /// map constant chat_alt to chat-alt.svg file
  static const String chat_alt = 'chat-alt.svg';

  /// map constant chat_remove to chat-remove.svg file
  static const String chat_remove = 'chat-remove.svg';

  /// map constant chat_warning to chat-warning.svg file
  static const String chat_warning = 'chat-warning.svg';

  /// map constant chat to chat.svg file
  static const String chat = 'chat.svg';

  /// map constant checkbox_intermediate to checkbox-intermediate.svg file
  static const String checkbox_intermediate = 'checkbox-intermediate.svg';

  /// map constant checkbox to checkbox.svg file
  static const String checkbox = 'checkbox.svg';

  /// map constant chevron_down to chevron-down.svg file
  static const String chevron_down = 'chevron-down.svg';

  /// map constant chevron_left to chevron-left.svg file
  static const String chevron_left = 'chevron-left.svg';

  /// map constant chevron_right to chevron-right.svg file
  static const String chevron_right = 'chevron-right.svg';

  /// map constant chevron_up to chevron-up.svg file
  static const String chevron_up = 'chevron-up.svg';

  /// map constant chevrons_down to chevrons-down.svg file
  static const String chevrons_down = 'chevrons-down.svg';

  /// map constant chevrons_left to chevrons-left.svg file
  static const String chevrons_left = 'chevrons-left.svg';

  /// map constant chevrons_right to chevrons-right.svg file
  static const String chevrons_right = 'chevrons-right.svg';

  /// map constant chevrons_up to chevrons-up.svg file
  static const String chevrons_up = 'chevrons-up.svg';

  /// map constant circle to circle.svg file
  static const String circle = 'circle.svg';

  /// map constant clip to clip.svg file
  static const String clip = 'clip.svg';

  /// map constant clipboard to clipboard.svg file
  static const String clipboard = 'clipboard.svg';

  /// map constant close to close.svg file
  static const String close = 'close.svg';

  /// map constant cloud_crossed to cloud-crossed.svg file
  static const String cloud_crossed = 'cloud-crossed.svg';

  /// map constant cloud_upload to cloud-upload.svg file
  static const String cloud_upload = 'cloud-upload.svg';

  /// map constant cloud to cloud.svg file
  static const String cloud = 'cloud.svg';

  /// map constant code_alt to code-alt.svg file
  static const String code_alt = 'code-alt.svg';

  /// map constant code to code.svg file
  static const String code = 'code.svg';

  /// map constant coffee to coffee.svg file
  static const String coffee = 'coffee.svg';

  /// map constant colours to colours.svg file
  static const String colours = 'colours.svg';

  /// map constant component to component.svg file
  static const String component = 'component.svg';

  /// map constant contact_book to contact-book.svg file
  static const String contact_book = 'contact-book.svg';

  /// map constant contrast to contrast.svg file
  static const String contrast = 'contrast.svg';

  /// map constant control_centre to control-centre.svg file
  static const String control_centre = 'control-centre.svg';

  /// map constant controls_alt to controls-alt.svg file
  static const String controls_alt = 'controls-alt.svg';

  /// map constant controls_vertical_alt to controls-vertical-alt.svg file
  static const String controls_vertical_alt = 'controls-vertical-alt.svg';

  /// map constant controls to controls.svg file
  static const String controls = 'controls.svg';

  /// map constant copy to copy.svg file
  static const String copy = 'copy.svg';

  /// map constant credit_card to credit-card.svg file
  static const String credit_card = 'credit-card.svg';

  /// map constant crop to crop.svg file
  static const String crop = 'crop.svg';

  /// map constant crossing to crossing.svg file
  static const String crossing = 'crossing.svg';

  /// map constant cup to cup.svg file
  static const String cup = 'cup.svg';

  /// map constant cursor to cursor.svg file
  static const String cursor = 'cursor.svg';

  /// map constant cut to cut.svg file
  static const String cut = 'cut.svg';

  /// map constant danger to danger.svg file
  static const String danger = 'danger.svg';

  /// map constant dashboard to dashboard.svg file
  static const String dashboard = 'dashboard.svg';

  /// map constant delete to delete.svg file
  static const String delete = 'delete.svg';

  /// map constant dialpad to dialpad.svg file
  static const String dialpad = 'dialpad.svg';

  /// map constant diamond to diamond.svg file
  static const String diamond = 'diamond.svg';

  /// map constant direction_left to direction-left.svg file
  static const String direction_left = 'direction-left.svg';

  /// map constant direction_right to direction-right.svg file
  static const String direction_right = 'direction-right.svg';

  /// map constant directions_left to directions-left.svg file
  static const String directions_left = 'directions-left.svg';

  /// map constant directions_right to directions-right.svg file
  static const String directions_right = 'directions-right.svg';

  /// map constant disc to disc.svg file
  static const String disc = 'disc.svg';

  /// map constant dolar to dolar.svg file
  static const String dolar = 'dolar.svg';

  /// map constant download to download.svg file
  static const String download = 'download.svg';

  /// map constant drop to drop.svg file
  static const String drop = 'drop.svg';

  /// map constant ear to ear.svg file
  static const String ear = 'ear.svg';

  /// map constant edit to edit.svg file
  static const String edit = 'edit.svg';

  /// map constant ellypsis_vertical to ellypsis-vertical.svg file
  static const String ellypsis_vertical = 'ellypsis-vertical.svg';

  /// map constant ellypsis to ellypsis.svg file
  static const String ellypsis = 'ellypsis.svg';

  /// map constant entrance to entrance.svg file
  static const String entrance = 'entrance.svg';

  /// map constant envelope_alt to envelope-alt.svg file
  static const String envelope_alt = 'envelope-alt.svg';

  /// map constant envelope to envelope.svg file
  static const String envelope = 'envelope.svg';

  /// map constant error to error.svg file
  static const String error = 'error.svg';

  /// map constant exit to exit.svg file
  static const String exit = 'exit.svg';

  /// map constant explore to explore.svg file
  static const String explore = 'explore.svg';

  /// map constant extension to extension.svg file
  static const String extension = 'extension.svg';

  /// map constant eye_closed to eye-closed.svg file
  static const String eye_closed = 'eye-closed.svg';

  /// map constant eye_crossed to eye-crossed.svg file
  static const String eye_crossed = 'eye-crossed.svg';

  /// map constant eye to eye.svg file
  static const String eye = 'eye.svg';

  /// map constant favourite to favourite.svg file
  static const String favourite = 'favourite.svg';

  /// map constant feather to feather.svg file
  static const String feather = 'feather.svg';

  /// map constant feed to feed.svg file
  static const String feed = 'feed.svg';

  /// map constant file to file.svg file
  static const String file = 'file.svg';

  /// map constant film to film.svg file
  static const String film = 'film.svg';

  /// map constant filter to filter.svg file
  static const String filter = 'filter.svg';

  /// map constant fit_ to fit.svg file
  static const String fit_ = 'fit.svg';

  /// map constant flag to flag.svg file
  static const String flag = 'flag.svg';

  /// map constant flower to flower.svg file
  static const String flower = 'flower.svg';

  /// map constant folder_add to folder-add.svg file
  static const String folder_add = 'folder-add.svg';

  /// map constant folder_remove to folder-remove.svg file
  static const String folder_remove = 'folder-remove.svg';

  /// map constant folder_warning to folder-warning.svg file
  static const String folder_warning = 'folder-warning.svg';

  /// map constant folder to folder.svg file
  static const String folder = 'folder.svg';

  /// map constant forward to forward.svg file
  static const String forward = 'forward.svg';

  /// map constant glasses to glasses.svg file
  static const String glasses = 'glasses.svg';

  /// map constant grid_alt to grid-alt.svg file
  static const String grid_alt = 'grid-alt.svg';

  /// map constant grid_small to grid-small.svg file
  static const String grid_small = 'grid-small.svg';

  /// map constant grid to grid.svg file
  static const String grid = 'grid.svg';

  /// map constant hamburger to hamburger.svg file
  static const String hamburger = 'hamburger.svg';

  /// map constant happy_face to happy-face.svg file
  static const String happy_face = 'happy-face.svg';

  /// map constant hash to hash.svg file
  static const String hash = 'hash.svg';

  /// map constant hdr to hdr.svg file
  static const String hdr = 'hdr.svg';

  /// map constant headphones to headphones.svg file
  static const String headphones = 'headphones.svg';

  /// map constant hearing_disability to hearing-disability.svg file
  static const String hearing_disability = 'hearing-disability.svg';

  /// map constant help to help.svg file
  static const String help = 'help.svg';

  /// map constant history to history.svg file
  static const String history = 'history.svg';

  /// map constant home_alt to home-alt.svg file
  static const String home_alt = 'home-alt.svg';

  /// map constant home_alt2 to home-alt2.svg file
  static const String home_alt2 = 'home-alt2.svg';

  /// map constant home to home.svg file
  static const String home = 'home.svg';

  /// map constant horn to horn.svg file
  static const String horn = 'horn.svg';

  /// map constant hourglass to hourglass.svg file
  static const String hourglass = 'hourglass.svg';

  /// map constant image to image.svg file
  static const String image = 'image.svg';

  /// map constant inbox_alt to inbox-alt.svg file
  static const String inbox_alt = 'inbox-alt.svg';

  /// map constant inbox to inbox.svg file
  static const String inbox = 'inbox.svg';

  /// map constant info to info.svg file
  static const String info = 'info.svg';

  /// map constant iphone to iphone.svg file
  static const String iphone = 'iphone.svg';

  /// map constant justify to justify.svg file
  static const String justify = 'justify.svg';

  /// map constant key_ to key.svg file
  static const String key_ = 'key.svg';

  /// map constant language to language.svg file
  static const String language = 'language.svg';

  /// map constant laptop to laptop.svg file
  static const String laptop = 'laptop.svg';

  /// map constant layers to layers.svg file
  static const String layers = 'layers.svg';

  /// map constant layout_left to layout-left.svg file
  static const String layout_left = 'layout-left.svg';

  /// map constant layout_right to layout-right.svg file
  static const String layout_right = 'layout-right.svg';

  /// map constant lightbulb to lightbulb.svg file
  static const String lightbulb = 'lightbulb.svg';

  /// map constant line_chart to line-chart.svg file
  static const String line_chart = 'line-chart.svg';

  /// map constant link to link.svg file
  static const String link = 'link.svg';

  /// map constant list_alt to list-alt.svg file
  static const String list_alt = 'list-alt.svg';

  /// map constant list_view to list-view.svg file
  static const String list_view = 'list-view.svg';

  /// map constant list to list.svg file
  static const String list = 'list.svg';

  /// map constant location to location.svg file
  static const String location = 'location.svg';

  /// map constant lock_alt_open to lock-alt-open.svg file
  static const String lock_alt_open = 'lock-alt-open.svg';

  /// map constant lock_alt to lock-alt.svg file
  static const String lock_alt = 'lock-alt.svg';

  /// map constant lock_open to lock-open.svg file
  static const String lock_open = 'lock-open.svg';

  /// map constant lock to lock.svg file
  static const String lock = 'lock.svg';

  /// map constant map to map.svg file
  static const String map = 'map.svg';

  /// map constant marker to marker.svg file
  static const String marker = 'marker.svg';

  /// map constant mask to mask.svg file
  static const String mask = 'mask.svg';

  /// map constant maximise to maximise.svg file
  static const String maximise = 'maximise.svg';

  /// map constant microphone to microphone.svg file
  static const String microphone = 'microphone.svg';

  /// map constant minimise to minimise.svg file
  static const String minimise = 'minimise.svg';

  /// map constant minus to minus.svg file
  static const String minus = 'minus.svg';

  /// map constant moon to moon.svg file
  static const String moon = 'moon.svg';

  /// map constant mouse to mouse.svg file
  static const String mouse = 'mouse.svg';

  /// map constant music to music.svg file
  static const String music = 'music.svg';

  /// map constant mute to mute.svg file
  static const String mute = 'mute.svg';

  /// map constant neutral_face to neutral-face.svg file
  static const String neutral_face = 'neutral-face.svg';

  /// map constant new_ to new.svg file
  static const String new_ = 'new.svg';

  /// map constant news to news.svg file
  static const String news = 'news.svg';

  /// map constant next_alt to next-alt.svg file
  static const String next_alt = 'next-alt.svg';

  /// map constant next to next.svg file
  static const String next = 'next.svg';

  /// map constant night_mode to night-mode.svg file
  static const String night_mode = 'night-mode.svg';

  /// map constant no_entry to no-entry.svg file
  static const String no_entry = 'no-entry.svg';

  /// map constant not_allowed to not-allowed.svg file
  static const String not_allowed = 'not-allowed.svg';

  /// map constant notebook to notebook.svg file
  static const String notebook = 'notebook.svg';

  /// map constant octagon to octagon.svg file
  static const String octagon = 'octagon.svg';

  /// map constant ok_circle to ok-circle.svg file
  static const String ok_circle = 'ok-circle.svg';

  /// map constant ok to ok.svg file
  static const String ok = 'ok.svg';

  /// map constant origin to origin.svg file
  static const String origin = 'origin.svg';

  /// map constant pan to pan.svg file
  static const String pan = 'pan.svg';

  /// map constant paperclip to paperclip.svg file
  static const String paperclip = 'paperclip.svg';

  /// map constant pause_circle to pause-circle.svg file
  static const String pause_circle = 'pause-circle.svg';

  /// map constant pause to pause.svg file
  static const String pause = 'pause.svg';

  /// map constant pen to pen.svg file
  static const String pen = 'pen.svg';

  /// map constant people to people.svg file
  static const String people = 'people.svg';

  /// map constant person_add to person-add.svg file
  static const String person_add = 'person-add.svg';

  /// map constant person to person.svg file
  static const String person = 'person.svg';

  /// map constant phone to phone.svg file
  static const String phone = 'phone.svg';

  /// map constant pie_chart to pie-chart.svg file
  static const String pie_chart = 'pie-chart.svg';

  /// map constant pizza to pizza.svg file
  static const String pizza = 'pizza.svg';

  /// map constant placeholder to placeholder.svg file
  static const String placeholder = 'placeholder.svg';

  /// map constant plane to plane.svg file
  static const String plane = 'plane.svg';

  /// map constant play to play.svg file
  static const String play = 'play.svg';

  /// map constant plus to plus.svg file
  static const String plus = 'plus.svg';

  /// map constant poll to poll.svg file
  static const String poll = 'poll.svg';

  /// map constant power to power.svg file
  static const String power = 'power.svg';

  /// map constant presentation to presentation.svg file
  static const String presentation = 'presentation.svg';

  /// map constant previous_alt to previous-alt.svg file
  static const String previous_alt = 'previous-alt.svg';

  /// map constant previous to previous.svg file
  static const String previous = 'previous.svg';

  /// map constant print to print.svg file
  static const String print = 'print.svg';

  /// map constant qr to qr.svg file
  static const String qr = 'qr.svg';

  /// map constant radio_button_selected to radio-button-selected.svg file
  static const String radio_button_selected = 'radio-button-selected.svg';

  /// map constant radio_button to radio-button.svg file
  static const String radio_button = 'radio-button.svg';

  /// map constant radio to radio.svg file
  static const String radio = 'radio.svg';

  /// map constant rain to rain.svg file
  static const String rain = 'rain.svg';

  /// map constant rectangle to rectangle.svg file
  static const String rectangle = 'rectangle.svg';

  /// map constant redo to redo.svg file
  static const String redo = 'redo.svg';

  /// map constant refresh to refresh.svg file
  static const String refresh = 'refresh.svg';

  /// map constant remove to remove.svg file
  static const String remove = 'remove.svg';

  /// map constant repeat to repeat.svg file
  static const String repeat = 'repeat.svg';

  /// map constant restaurant to restaurant.svg file
  static const String restaurant = 'restaurant.svg';

  /// map constant return_ to return.svg file
  static const String return_ = 'return.svg';

  /// map constant retweet to retweet.svg file
  static const String retweet = 'retweet.svg';

  /// map constant rocket to rocket.svg file
  static const String rocket = 'rocket.svg';

  /// map constant rotate to rotate.svg file
  static const String rotate = 'rotate.svg';

  /// map constant rss to rss.svg file
  static const String rss = 'rss.svg';

  /// map constant sad_face to sad-face.svg file
  static const String sad_face = 'sad-face.svg';

  /// map constant save to save.svg file
  static const String save = 'save.svg';

  /// map constant search to search.svg file
  static const String search = 'search.svg';

  /// map constant send to send.svg file
  static const String send = 'send.svg';

  /// map constant settings to settings.svg file
  static const String settings = 'settings.svg';

  /// map constant share_android to share-android.svg file
  static const String share_android = 'share-android.svg';

  /// map constant share_ios to share-ios.svg file
  static const String share_ios = 'share-ios.svg';

  /// map constant share to share.svg file
  static const String share = 'share.svg';

  /// map constant shield to shield.svg file
  static const String shield = 'shield.svg';

  /// map constant shift to shift.svg file
  static const String shift = 'shift.svg';

  /// map constant shuffle to shuffle.svg file
  static const String shuffle = 'shuffle.svg';

  /// map constant sign_language to sign-language.svg file
  static const String sign_language = 'sign-language.svg';

  /// map constant signal_alt to signal-alt.svg file
  static const String signal_alt = 'signal-alt.svg';

  /// map constant signal to signal.svg file
  static const String signal = 'signal.svg';

  /// map constant skull to skull.svg file
  static const String skull = 'skull.svg';

  /// map constant smartphone to smartphone.svg file
  static const String smartphone = 'smartphone.svg';

  /// map constant snow to snow.svg file
  static const String snow = 'snow.svg';

  /// map constant sort_down to sort-down.svg file
  static const String sort_down = 'sort-down.svg';

  /// map constant sort_up to sort-up.svg file
  static const String sort_up = 'sort-up.svg';

  /// map constant sorting to sorting.svg file
  static const String sorting = 'sorting.svg';

  /// map constant sounds to sounds.svg file
  static const String sounds = 'sounds.svg';

  /// map constant spam to spam.svg file
  static const String spam = 'spam.svg';

  /// map constant stack to stack.svg file
  static const String stack = 'stack.svg';

  /// map constant star to star.svg file
  static const String star = 'star.svg';

  /// map constant stats_alt to stats-alt.svg file
  static const String stats_alt = 'stats-alt.svg';

  /// map constant stats to stats.svg file
  static const String stats = 'stats.svg';

  /// map constant sticker to sticker.svg file
  static const String sticker = 'sticker.svg';

  /// map constant stop to stop.svg file
  static const String stop = 'stop.svg';

  /// map constant stopwatch to stopwatch.svg file
  static const String stopwatch = 'stopwatch.svg';

  /// map constant suitcase_alt to suitcase-alt.svg file
  static const String suitcase_alt = 'suitcase-alt.svg';

  /// map constant suitcase to suitcase.svg file
  static const String suitcase = 'suitcase.svg';

  /// map constant sun_cloud to sun-cloud.svg file
  static const String sun_cloud = 'sun-cloud.svg';

  /// map constant sun to sun.svg file
  static const String sun = 'sun.svg';

  /// map constant sunset to sunset.svg file
  static const String sunset = 'sunset.svg';

  /// map constant support_alt to support-alt.svg file
  static const String support_alt = 'support-alt.svg';

  /// map constant support to support.svg file
  static const String support = 'support.svg';

  /// map constant swap_horizontal to swap-horizontal.svg file
  static const String swap_horizontal = 'swap-horizontal.svg';

  /// map constant swap_vertical to swap-vertical.svg file
  static const String swap_vertical = 'swap-vertical.svg';

  /// map constant switch_off to switch-off.svg file
  static const String switch_off = 'switch-off.svg';

  /// map constant switch_on to switch-on.svg file
  static const String switch_on = 'switch-on.svg';

  /// map constant table_horizontal to table-horizontal.svg file
  static const String table_horizontal = 'table-horizontal.svg';

  /// map constant table_vertical to table-vertical.svg file
  static const String table_vertical = 'table-vertical.svg';

  /// map constant tag_alt to tag-alt.svg file
  static const String tag_alt = 'tag-alt.svg';

  /// map constant tag to tag.svg file
  static const String tag = 'tag.svg';

  /// map constant text to text.svg file
  static const String text = 'text.svg';

  /// map constant thermometer to thermometer.svg file
  static const String thermometer = 'thermometer.svg';

  /// map constant thumb_down to thumb-down.svg file
  static const String thumb_down = 'thumb-down.svg';

  /// map constant thumb_up to thumb-up.svg file
  static const String thumb_up = 'thumb-up.svg';

  /// map constant thunder to thunder.svg file
  static const String thunder = 'thunder.svg';

  /// map constant time to time.svg file
  static const String time = 'time.svg';

  /// map constant timer to timer.svg file
  static const String timer = 'timer.svg';

  /// map constant tool to tool.svg file
  static const String tool = 'tool.svg';

  /// map constant train to train.svg file
  static const String train = 'train.svg';

  /// map constant transport to transport.svg file
  static const String transport = 'transport.svg';

  /// map constant trending_down to trending-down.svg file
  static const String trending_down = 'trending-down.svg';

  /// map constant trending_up to trending-up.svg file
  static const String trending_up = 'trending-up.svg';

  /// map constant turn_left to turn-left.svg file
  static const String turn_left = 'turn-left.svg';

  /// map constant turn_right to turn-right.svg file
  static const String turn_right = 'turn-right.svg';

  /// map constant tv to tv.svg file
  static const String tv = 'tv.svg';

  /// map constant typography to typography.svg file
  static const String typography = 'typography.svg';

  /// map constant umbrella to umbrella.svg file
  static const String umbrella = 'umbrella.svg';

  /// map constant undo to undo.svg file
  static const String undo = 'undo.svg';

  /// map constant upload to upload.svg file
  static const String upload = 'upload.svg';

  /// map constant user to user.svg file
  static const String user = 'user.svg';

  /// map constant verified to verified.svg file
  static const String verified = 'verified.svg';

  /// map constant vertical to vertical.svg file
  static const String vertical = 'vertical.svg';

  /// map constant video to video.svg file
  static const String video = 'video.svg';

  /// map constant voicemail to voicemail.svg file
  static const String voicemail = 'voicemail.svg';

  /// map constant volume_loud to volume-loud.svg file
  static const String volume_loud = 'volume-loud.svg';

  /// map constant volume_off to volume-off.svg file
  static const String volume_off = 'volume-off.svg';

  /// map constant volume_quiet to volume-quiet.svg file
  static const String volume_quiet = 'volume-quiet.svg';

  /// map constant walking to walking.svg file
  static const String walking = 'walking.svg';

  /// map constant wallpaper to wallpaper.svg file
  static const String wallpaper = 'wallpaper.svg';

  /// map constant watch to watch.svg file
  static const String watch = 'watch.svg';

  /// map constant wheelchair to wheelchair.svg file
  static const String wheelchair = 'wheelchair.svg';

  /// map constant wifi to wifi.svg file
  static const String wifi = 'wifi.svg';

  /// map constant window to window.svg file
  static const String window = 'window.svg';

  /// map constant wine to wine.svg file
  static const String wine = 'wine.svg';

  /// map constant zoom_in to zoom-in.svg file
  static const String zoom_in = 'zoom-in.svg';

  /// map constant zoom_out to zoom-out.svg file
  static const String zoom_out = 'zoom-out.svg';
}
